@@ -1,10 +1,13 @@
 from django.db import models
 
-from ax3_model_extras.storages import get_upload_path
+from ax3_model_extras.storages import get_upload_path, get_storage
 
 
 class RedactorFile(models.Model):
-    file = models.FileField(upload_to=get_upload_path)
+    file = models.FileField(
+        upload_to=get_upload_path,
+        storage=get_storage(),
+    )
 
     name = models.CharField(max_length=255)
 
